@@ -37,17 +37,20 @@ extern "C" {
 #define av_packet_unref av_free_packet
 #endif
 
+#define HAVE_AVCODEC_FREE_CONTEXT (LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(55, 69, 100))
+#define HAVE_CH_LAYOUT (LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(57, 28, 100))
+
 wxFfmpegMediaDecoder::wxFfmpegMediaDecoder(): m_formatCtx(NULL), m_videoStream(-1), m_codecCtx(NULL), m_frame(NULL),
 		m_width(0), m_height(0) {
 	// nothing to do
 }
 
 wxFfmpegMediaDecoder::~wxFfmpegMediaDecoder() {
-    Close();
+	Close();
 }
 
 void wxFfmpegMediaDecoder::Init() {
-    // nothing to do
+	// nothing to do
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 0, 0)
 	av_register_all();
 #endif
@@ -99,8 +102,8 @@ unsigned int wxFfmpegMediaDecoder::GetStreamCount() {
 }
 
 wxSize wxFfmpegMediaDecoder::GetVideoSize() {
-    OpenVideoDecoder();
-    return m_codecCtx ? wxSize(m_codecCtx->width, m_codecCtx->height) : wxSize();
+	OpenVideoDecoder();
+	return m_codecCtx ? wxSize(m_codecCtx->width, m_codecCtx->height) : wxSize();
 }
 
 AVStream* wxFfmpegMediaDecoder::GetVideoStream() {
@@ -165,7 +168,11 @@ wxString wxFfmpegMediaDecoder::GetCodecName(unsigned int streamIndex) {
 }
 
 int wxFfmpegMediaDecoder::GetChannelNumber(unsigned int streamIndex) {
+#if HAVE_CH_LAYOUT
+	return m_formatCtx ? m_formatCtx->streams[streamIndex]->codecpar->ch_layout.nb_channels : -1;
+#else
 	return m_formatCtx ? m_formatCtx->streams[streamIndex]->codecpar->channels : -1;
+#endif
 }
 
 int wxFfmpegMediaDecoder::GetSampleRate(unsigned int streamIndex) {
@@ -213,15 +220,19 @@ bool wxFfmpegMediaDecoder::OpenVideoDecoder() {
 }
 
 void wxFfmpegMediaDecoder::CloseVideoDecoder() {
-    if (m_codecCtx)
-        avcodec_close(m_codecCtx); // close the codec
-    m_codecCtx = NULL;
+	if (m_codecCtx)
+#if HAVE_AVCODEC_FREE_CONTEXT
+		avcodec_free_context(&m_codecCtx);
+#else
+		avcodec_close(m_codecCtx); // close the codec
+#endif
+	m_codecCtx = NULL;
 }
 
 bool wxFfmpegMediaDecoder::BeginDecode(int width, int height) {
-    if (!m_formatCtx || !OpenVideoDecoder())
-        return false;
-    // video size
+	if (!m_formatCtx || !OpenVideoDecoder())
+		return false;
+	// video size
 	if (width == -1 || height == -1) {
 		m_width = m_codecCtx->width;
 		m_height = m_codecCtx->height;
@@ -231,31 +242,35 @@ bool wxFfmpegMediaDecoder::BeginDecode(int width, int height) {
 		m_width = w < width ? w : width;
 		m_height = w < width ? height : h;
 	}
-    // allocate video frame
-    m_frame = av_frame_alloc();
-    if (!m_frame) {
-        avcodec_close(m_codecCtx);
-        m_codecCtx = NULL;
-        return false;
-    }
-    return true;
+	// allocate video frame
+	m_frame = av_frame_alloc();
+	if (!m_frame) {
+#if HAVE_AVCODEC_FREE_CONTEXT
+		avcodec_free_context(&m_codecCtx);
+#else
+		avcodec_close(m_codecCtx);
+#endif
+		m_codecCtx = NULL;
+		return false;
+	}
+	return true;
 }
 
 bool wxFfmpegMediaDecoder::SetPosition(double pos, bool keyFrame, bool seekBackward) {
-    if (m_formatCtx == NULL)
-        return false;
+	if (m_formatCtx == NULL)
+		return false;
 	if (!m_frame && !BeginDecode())
 		return false;
-    int64_t timestamp = (int64_t) (pos * AV_TIME_BASE);
-    if (m_formatCtx->start_time != (int64_t)AV_NOPTS_VALUE)
-        timestamp += m_formatCtx->start_time;
-    avcodec_flush_buffers(m_codecCtx);
-    int flags = seekBackward ? AVSEEK_FLAG_BACKWARD : 0;
-    if (!keyFrame)
-    	flags = flags|AVSEEK_FLAG_ANY;
-    bool res = av_seek_frame(m_formatCtx, -1, timestamp, flags) >= 0;
-    avcodec_flush_buffers(m_codecCtx);
-    return res;
+	int64_t timestamp = (int64_t) (pos * AV_TIME_BASE);
+	if (m_formatCtx->start_time != (int64_t)AV_NOPTS_VALUE)
+		timestamp += m_formatCtx->start_time;
+	avcodec_flush_buffers(m_codecCtx);
+	int flags = seekBackward ? AVSEEK_FLAG_BACKWARD : 0;
+	if (!keyFrame)
+		flags = flags|AVSEEK_FLAG_ANY;
+	bool res = av_seek_frame(m_formatCtx, -1, timestamp, flags) >= 0;
+	avcodec_flush_buffers(m_codecCtx);
+	return res;
 }
 
 double wxFfmpegMediaDecoder::GetPosition() {
@@ -333,7 +348,7 @@ wxImage wxFfmpegMediaDecoder::GetNextFrame() {
 
 void wxFfmpegMediaDecoder::EndDecode() {
 	av_frame_free(&m_frame);
-    CloseVideoDecoder();
+	CloseVideoDecoder();
 }
 
 /** Returns a comma separated list of short names for the format. */
